==> haskell-coinbase-pro-0.9.3.2-236-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-3Q5AQMpTkHHHnVYQ30l8FC
key:                  coinbase-pro-0.9.3.2-3Q5AQMpTkHHHnVYQ30l8FC
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  9c3651aaf90582bdb3f298cdaf0d3e10
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-3Q5AQMpTkHHHnVYQ30l8FC
depends:
    HsOpenSSL-0.11.7.9-HHb0ZKEepX86QM4tZpagl5
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM
    aeson-casing-0.2.0.0-6AQb2l1NoHZH3ynhCCgijH
    async-2.2.5-EyV9emCuOIPGUIakwGPKTd base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-EmQIMz5ymXy1lbqLHnuFM5 exceptions-0.10.5
    http-api-data-0.5.1-8S1wn4jvPkQF7HoXpoxtJs
    http-client-0.7.17-4ADmMJlTJbdEGFQAXSREop
    http-client-tls-0.3.6.3-17nunTENAGkF52mUVERX9N
    http-streams-0.8.9.9-Cbe5ZYhCa4RKdytl5KzSzg
    http-types-0.12.4-84PTldXFVlSHvwiFY4h2Wj
    io-streams-1.5.2.2-GjT3I6xfddh2Lh2US4N804
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-4LxzNodBXIzL8bUGme1k8m
    servant-0.20.2-GU4dtB5bLs9D5ExduUmLSF
    servant-client-0.20-1F6yR9ApBLG9bfswzGWToY
    servant-client-core-0.20.2-907ZdE0WOGwDdHetHdf4Mw
    tasty-1.4.3-1VgnHOByr8AIto1CnZp8DF
    tasty-hunit-0.10.1-q71iukSCC7EOanHbVCs3z text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-5bhPYStemVJHgHjB0ZNuh7
    unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG
    uuid-1.3.16-5gzfU57PjbAAPEaoMEMRoj
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX
    websockets-0.12.7.3-CgUQadaexo2Fecw35OV3EB
    wuss-2.0.1.1-EkkXUa6wuWV9ODlX8VOis6

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-9BXH3kAFBOlAG6ywBzqIv1
key:                  coinbase-pro-0.9.3.2-9BXH3kAFBOlAG6ywBzqIv1
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  4940a2d181bb24d6ab32da631e0b88d7
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-9BXH3kAFBOlAG6ywBzqIv1
depends:
    HsOpenSSL-0.11.7.9-2jzkn0T9f0OCYFODYYTVs4
    aeson-2.1.2.1-BogEXKsQPCa9ALgQQ034ff
    aeson-casing-0.2.0.0-2m4yLzQUz4kHfESwbZpVDo
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-AhJRgKpvPmBITEZW3Idbwt exceptions-0.10.5
    http-api-data-0.5.1-83M5cJsEa0FKWGHgvoMn7k
    http-client-0.7.17-GjKLViTNtmdDUQUFfydSDc
    http-client-tls-0.3.6.3-GNrwXgXxJ3CGJjqMAHwDh1
    http-streams-0.8.9.9-CFig3fQHC521p3e1fIlPir
    http-types-0.12.4-ELP3cONQaOf7BJAjzf0skh
    io-streams-1.5.2.2-8DZmojrYPshGe0PTu2iEqz
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    servant-0.20.2-CPxsnbRtMuI51iqHKme7ND
    servant-client-0.20-8lBiQhGe1qc55uIycLv3ZY
    servant-client-core-0.20.2-2QgjnjgxfLTBrm9royZ1kT
    tasty-1.4.3-1VgnHOByr8AIto1CnZp8DF
    tasty-hunit-0.10.1-q71iukSCC7EOanHbVCs3z text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-K7woPECtgpMDMlOW2Qconz
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd
    uuid-1.3.16-872C2ncsprsByedHsPUft7
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O
    websockets-0.12.7.3-72Zvbbu0qQwCdP7WcLLvsJ
    wuss-2.0.1.1-21bAgQYd0E6J58XldOuxKX

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
